#-/*
#- Title  : mnt_exp_dmp.ksh
#- Author : EXADIME LLC
#- Created: 29-Jun-2017
#- Updated: 29-Jun-2017
#- Release: 1.0.0
#- Purpose: This script does logical export of the given database.
#- History: N/A
#-*/

. ${exa_home}/ini/unix.ini

#Header
#1.Declarations
ora_sid=""
loc_sid=""
dmp_dir=""
par_file=""
cut_files=""
file_size=""
db_env=""
keep_days=""
label=""
title=""
esp=""
msg=""
sid=""

#2.Input
while [ "${#}" != "0" ]
do
        case ${1} in
                -sid|-s)
                shift
                if [ "${1}" != "" ]
                then
                        ora_sid=${1}
                        shift
                fi
                ;;
                -locsid|-o)
                shift
                if [ "${1}" != "" ]
                then
                        loc_sid=${1}
                        shift
                fi
                ;;
                -dmpdir|-d)
                shift
                if [ "${1}" != "" ]
                then
                        dmp_dir=${1}
                        shift
                fi
                ;;
                -parfile|-p)
                shift
                if [ "${1}" != "" ]
                then
                        par_file=${1}
                        shift
                fi
                ;;
                -cutfiles|-c)
                shift
                if [ "${1}" != "" ]
                then
                        cut_files=${1}
                        shift
                fi
                ;;
                -filesize|-z)
                shift
                if [ "${1}" != "" ]
                then
                        file_size=${1}
                        shift
                fi
                ;;
                -dbenv|-n)
                shift
                if [ "${1}" != "" ]
                then
                        db_env=${1}
                        shift
                fi
                ;;
                -keepdays|-k)
                shift
                if [ "${1}" != "" ]
                then
                        keep_days=${1}
                        shift
                fi
                ;;                
                -label|-l)
                shift
                if [ "${1}" != "" ]
                then
                        label=${1}
                        shift
                fi
                ;;
                -title|-t)
                shift
                if [ "${1}" != "" ]
                then
                        title=${1}
                        shift
                fi
                ;;
		-esp|-e)
                shift
                if [ "${1}" != "" ]
                then
                        esp=${1}
                        shift
                fi
                ;;
                -help|-h)
                echo ""
                echo "Argument             Description"
                echo "---------------------------------------------------------"
                echo "-sid|-s              SID."
                echo "-locsid|-o           Local SID."
                echo "-dmpdir|-d           Directory of dump file."
                echo "-parfile|-p          Name of par file."
                echo "-cutfiles|-c         Cut (split) files (y/n)?"                                
                echo "-filesize|-z         Size of each split file (n[k|m])." 
		echo "-dbenv|-n            Is db env template required?"
		echo "-keepdays|-k         No of days to keep old backup files."
                echo "-label|-l            Label of dmp file."
		echo "-title|-t            Title of report."
		echo "-esp|-e              Notification (email/sms/pager) code."
                exit 0;
                ;;
                *)
                echo "Bad argument: ${1}"
                echo "Use -help option to see correct usage."
                exit 0;
                ;;
        esac
done

#3.Input Validation
#3.1.Check optional fields.
if [ "${label}" = "" ]
then
	rpt_file=${rpt_dir}/mnt_exp_dmp_${time_stamp}.rpt
	alt_file=${alt_dir}/mnt_exp_dmp_${time_stamp}.alt
	log_file=${log_dir}/mnt_exp_dmp_${time_stamp}.log
	tmp_file=${tmp_dir}/mnt_exp_dmp_${time_stamp}.tmp
	dmp_file=${dmp_dir}/mnt_exp_dmp_${time_stamp}.dmp.Z
	spt_file=${dmp_dir}/mnt_exp_dmp_${time_stamp}_
	exp_pipe=${pie_dir}/exp_mnt_exp_dmp_${time_stamp}.pie
	spt_pipe=${pie_dir}/spt_mnt_exp_dmp_${time_stamp}.pie
else
	rpt_file=${rpt_dir}/${label}_mnt_exp_dmp_${time_stamp}.rpt
	alt_file=${alt_dir}/${label}_mnt_exp_dmp_${time_stamp}.alt
	log_file=${log_dir}/${label}_mnt_exp_dmp_${time_stamp}.log
	tmp_file=${tmp_dir}/${label}_mnt_exp_dmp_${time_stamp}.tmp
	dmp_file=${dmp_dir}/${label}_mnt_exp_dmp_${time_stamp}.dmp.Z
	spt_file=${dmp_dir}/${label}_mnt_exp_dmp_${time_stamp}_
	exp_pipe=${pie_dir}/${label}_exp_mnt_exp_dmp_${time_stamp}.pie
	spt_pipe=${pie_dir}/${label}_spt_mnt_exp_dmp_${time_stamp}.pie
fi

if [ "${db_env}" = "" ]
then
	db_env="n"
fi

if [ "${title}" = "" ]
then
	title="Export Dump"
fi

if [ "${esp}" = "" ]
then
	esp="${mnt_esp}"
fi

if [ "${cut_files}" = "" ]
then
	cut_files="n"
fi

#3.2.Check mandatory fields.
if [ "${ora_sid}" = "" ]
then
	if [ "${loc_sid}" = "" ]
	then
		echo_alt_title "${title}"
		echo "Local SID entry is blank!" >> ${alt_file}
		msg="Local SID entry is blank!"
		echo_double_line ${alt_file}
		send_espn "${esp}" "${title}" "${alt_file}" "${msg}"
		exit 0
	else
		f=0
		for i in `grep -v '^#' ${ora_tab}|grep '^[^ ]'|grep ${loc_sid}`
		do
			a=`echo ${i}|awk -F: '{print $1}'`
			b=`echo ${i}|awk -F: '{print $2}'`
			
			if [ "${a}" = "${loc_sid}" ]
			then
				echo "Enter Username \c"
				read usn
				echo "Enter Password \c"
				stty -echo
				read pwd
				stty echo
				credentials="${usn}/${pwd}"
				. ${exa_home}/unix/mnt_sw_db.ksh ${loc_sid}
				f=1
			fi
		done
		if [ "${f}" = "0" ]
		then
			echo_alt_title "${title}"
			echo "Local SID entry is invalid!" >> ${alt_file}
			msg="Local SID entry is invalid!"
			echo_double_line ${alt_file}
			send_espn "${esp}" "${title}" "${alt_file}" "${msg}"
			exit 0
		fi
	fi	
else
	if test `echo ${ora_sid}|grep "/"|wc -l` -eq 1
	then
		if [ "${loc_sid}" = "" ]
		then
			echo_alt_title "${title}"
			echo "Local SID entry is blank!" >> ${alt_file}
			msg="Local SID entry is blank!"
			echo_double_line ${alt_file}
			send_espn "${esp}" "${title}" "${alt_file}" "${msg}"
			exit 0
		else
			f=0
			for i in `grep -v '^#' ${ora_tab}|grep '^[^ ]'|grep ${loc_sid}`
			do
				a=`echo ${i}|awk -F: '{print $1}'`
				b=`echo ${i}|awk -F: '{print $2}'`
				
				if [ "${a}" = "${loc_sid}" ]
				then
					credentials=${ora_sid}
					. ${exa_home}/unix/mnt_sw_db.ksh ${loc_sid}
					f=1
				fi
			done
			if [ "${f}" = "0" ]
			then
				echo_alt_title "${title}"
				echo "Local SID entry is invalid!" >> ${alt_file}
				msg="Local SID entry is invalid!"
				echo_double_line ${alt_file}
				send_espn "${esp}" "${title}" "${alt_file}" "${msg}"
				exit 0
			fi					
		fi
	else
		f=0
		for i in `grep -v '^#' ${ora_tab}|grep '^[^ ]'|grep ${ora_sid}`
		do
			a=`echo ${i}|awk -F: '{print $1}'`
			b=`echo ${i}|awk -F: '{print $2}'`
			
			if [ "${a}" = "${ora_sid}" ]
			then
				credentials="/ as sysdba"
				. ${exa_home}/unix/mnt_sw_db.ksh ${ora_sid}
				f=1
			fi	
		done
		if [ "${f}" = "0" ]
		then
			echo_alt_title "${title}"
			echo "Oracle SID entry is invalid!" >> ${alt_file}
			msg="Oracle SID entry is invalid!"
			echo_double_line ${alt_file}
			send_espn "${esp}" "${title}" "${alt_file}" "${msg}"
			exit 0
		fi
	fi	
fi

if [ ! "${ora_sid}" = "ALL" ]; then
	if [ ! "${ora_sid}" = "" ]; then
		sid=`echo ${ora_sid}|cut -d@ -f2|cut -d/ -f1`
	else
		if [ ! "`echo ${credentials}|cut -d@ -f2`" = "" ]; then
			sid=`echo ${credentials}|cut -d@ -f2|cut -d/ -f1`
		else
			sid=${loc_sid}
		fi
	fi
fi

if [ "${dmp_dir}" = "" ]
then
        echo_alt_title "${title}"
	echo "Dump directory entry is blank!" >> ${alt_file}
	msg="Dump directory entry is blank!"
	echo_double_line ${alt_file}
	send_espn "${esp}" "${title}" "${alt_file}" "${msg}"
	exit 0
else	
	if ! [ -d ${dmp_dir} ]
	then
		echo_alt_title "${title}"
		echo "Dump directory does not exist!" >> ${alt_file}
		msg="Dump directory does not exist!"
		echo_double_line ${alt_file}
		send_espn "${esp}" "${title}" "${alt_file}" "${msg}"
		exit 0
	else
		if ! [ -w ${dmp_dir} ]
		then
			echo_alt_title "${title}"
			echo "Dump directory is not writable!" >> ${alt_file}
			msg="Dump directory is not writable!"
			echo_double_line ${alt_file}
			send_espn "${esp}" "${title}" "${alt_file}" "${msg}"
			exit 0
		fi		
	fi
fi

if [ "${par_file}" = "" ]
then
        echo_alt_title "${title}"
	echo "Par file entry is blank!" >> ${alt_file}
	msg="Par file entry is blank!"
	echo_double_line ${alt_file}
	send_espn "${esp}" "${title}" "${alt_file}" "${msg}"
	exit 0
else	
	if test `echo ${par_file}|grep "{"|grep "}"|wc -l` -eq 0
	then
		if ! [ -f ${par_file} ]
		then
			echo_alt_title "${title}"
			echo "Par file does not exist!" >> ${alt_file}
			msg="Par file does not exist!"
			echo_double_line ${alt_file}
			send_espn "${esp}" "${title}" "${alt_file}" "${msg}"
			exit 0
		else
			if ! [ -r ${par_file} ]
			then
				echo_alt_title "${title}"
				echo "Par file is not readable!" >> ${alt_file}
				msg="Par file is not readable!"
				echo_double_line ${alt_file}
				send_espn "${esp}" "${title}" "${alt_file}" "${msg}"
				exit 0
			fi
		fi
	fi	
fi

if [ "${cut_files}" = "y" -o "${cut_files}" = "Y" ]
then
	if [ "${file_size}" = "" ]
	then
		echo_alt_title "${title}"
		echo "File size entry is blank!" >> ${alt_file}
		msg="File size entry is blank!"
		echo_double_line ${alt_file}
		send_espn "${esp}" "${title}" "${alt_file}" "${msg}"
		exit 0
	fi		
fi

#4.Sanity Checks
#4.1.Check if database is up. If not, send esp notifications as instructed and exit.
if [[ ! "${ora_sid}" = "" && ! "${ora_sid}" = "ALL" ]]; then
	if [[ `echo ${ora_sid}|grep "/"|wc -l` -ne 1 && `echo ${ora_sid}|grep "@"|wc -l` -ne 1 ]]; then
		if [ "`ps -eo user,pid,args|grep pmon_${ora_sid}|awk '$3 !~ /grep/ {print $3}'`" = "" ]
		then
			echo_alt_title "${title}"
			echo "Database ${sid} on `hostname` is not up!" >> ${alt_file}
			msg="Database ${sid} on `hostname` is not up!"
			echo_double_line ${alt_file}
			send_espn "${esp}" "${title}" "${alt_file}" "${msg}"
			exit 0
		fi
	fi	
fi

#4.2.Verify if password is correct or sysdba privilege exists. If not, send esp notifications as instructed and exit.
sqlplus -s/nolog >> ${tmp_file} << EOF
	${credentials}
EOF

if grep ORA- ${tmp_file} > /dev/null
then
        echo_alt_title "${title}"
	echo "Connect to database ${sid} failed!" >> ${alt_file}
	msg="Connect to database ${sid} failed!"
	echo_double_line ${alt_file}
	send_espn "${esp}" "${title}" "${alt_file}" "${msg}"
	exit 0
fi

rm -f ${tmp_file}

#Body
#1.Make pipe(s).
/usr/sbin/mknod ${exp_pipe} p
/usr/sbin/mknod ${spt_pipe} p

#2.Split compressed dump file using pipe.
if [ "${cut_files}" = "y" -o "${cut_files}" = "Y" ]
then
	split -b ${file_size} - ${spt_file} < ${spt_pipe} > /dev/null &
fi

#3.Compress dump file using pipe.
if [ "${cut_files}" = "y" -o "${cut_files}" = "Y" ]
then
	compress < ${exp_pipe} > ${spt_pipe} &
else
	compress < ${exp_pipe} > ${dmp_file} &
fi

#4.Wait a few seconds.
sleep 5

#5.Do export.
if test `echo ${par_file}|grep "{"|grep "}"|wc -l` -eq 0
then
	if [[ "${ora_sid}" = "" && "${loc_sid}" != "" ]]
	then
		exp "${usn}" file=${exp_pipe} parfile=${par_file} log=${log_file}
	else
		exp "'${credentials}'" file=${exp_pipe} parfile=${par_file} > ${log_file} 2>&1
	fi	
else
	if [[ "${ora_sid}" = "" && "${loc_sid}" != "" ]]
	then
		exp "${usn}" file=${exp_pipe} `echo ${par_file}|sed 's/{//'|sed 's/}//'` log=${log_file}
	else
		exp "'${credentials}'" file=${exp_pipe} `echo ${par_file}|sed 's/{//'|sed 's/}//'` > ${log_file} 2>&1
	fi	
fi

#Note: Because exp writes to standard error we need to redirect standard error so cron will not mail erroneously.  

#6.Remove pipe(s).
rm -f ${exp_pipe}
rm -f ${spt_pipe}

#7.Generate db env template.
if [ "${db_env}" = "y" -o "${db_env}" = "Y" ]
then
	`sqlplus -s/nolog >> ${tmp_file} << EOF
		connect ${credentials}
		@db_env.sql
		exit;
	EOF`

	if [ -f ${tmp_file} ]
	then
		cp ${tmp_file} ${dmp_dir}
		compress "${dmp_dir}/`basename ${tmp_file}`"
	fi
fi

#8.Copy log file into dmp directory and compress.
if [ -f ${log_file} ]
then
	cp ${log_file} ${dmp_dir}
	compress "${dmp_dir}/`basename ${log_file}`"
fi

#9.Remove old backup files.
if ! [ "${keep_days}" = "" ]
then
	if grep "Export terminated successfully" ${log_file} > /dev/null
	then
		if [ "${label}" = "" ]
		then
			for i in `find ${dmp_dir} -name "mnt_exp_dmp*" -mtime +${keep_days} -print`
			do
				rm -f ${i}
			done
		else
			for i in `find ${dmp_dir} -name "${label}_mnt_exp_dmp*" -mtime +${keep_days} -print`
			do
				rm -f ${i}
			done
		fi
	fi	
fi

#10.Check for errors in export log and send esp notifications as instructed.
if grep "Export terminated successfully" ${log_file} > /dev/null
then
	echo_rpt_title "${title}"
	if tail -1 ${log_file}|grep "without warnings." > /dev/null
	then
		echo "Export of database ${sid} on host `hostname` completed successfully." >> ${rpt_file}
		msg="Export of database ${sid} on host `hostname` completed successfully."
	else
		echo "Export of database ${sid} on host `hostname` completed successfully with warnings." >> ${rpt_file}
		msg="Export of database ${sid} on host `hostname` completed successfully with warnings."
	fi
	
	if [[ "${db_env}" = "y" || "${db_env}" = "Y" ]] && [ ! -s ${tmp_file} ]
	then
		echo "But failed to generate db env template!" >> ${rpt_file}
		msg="${msg} But failed to generate db env template!"
	fi
	
	if [ "${cut_files}" = "y" -o "${cut_files}" = "Y" ]
	then
		echo "Dmp file(s)..." >> ${rpt_file}
		ls -1 ${spt_file}* >> ${rpt_file}
		ls -al ${spt_file}*|awk '{sum = sum + $5} {sum_mb=sum/(1024*1024)} END {print "of total size "sum_mb" MB."}' >> ${rpt_file}
	else
		echo "Dmp file is... ${dmp_file}" >> ${rpt_file}
	fi
	
	echo "Log file is... ${log_file}" >> ${rpt_file}
	echo_double_line ${rpt_file}
	send_espn "${esp}" "${title}" "${rpt_file}" "${msg}"
else
	echo_alt_title "${title}"
	echo "Export of database ${sid} on host `hostname` failed! See log file." >> ${alt_file}
	msg="Export of database ${sid} on host `hostname` failed! See log file."
	
	if [[ "${db_env}" = "y" || "${db_env}" = "Y" ]] && [ ! -s ${tmp_file} ]
	then
		echo "And also failed to generate db env template!" >> ${alt_file}
		msg="${msg} And also failed to generate db env template!"
	fi
	
	if [ "${cut_files}" = "y" -o "${cut_files}" = "Y" ]
	then
		echo "Dmp file(s)..." >> ${alt_file}
		ls -1 ${dmp_dir}/`basename ${dmp_file}|awk -F"." '{print $1}'`_* >> ${alt_file}
		ls -al ${dmp_dir}/`basename ${dmp_file}|awk -F"." '{print $1}'`_*|awk '{sum = sum + $5} {sum_mb=sum/(1024*1024)} END {print "of total size "sum_mb" MB."}' >> ${alt_file}		
	else
		echo "Dmp file is... ${dmp_file}" >> ${alt_file}
	fi
	
	echo "Log file is... ${log_file}" >> ${alt_file}
	echo_double_line ${alt_file}
        send_espn "${esp}" "${title}" "${alt_file}" "${msg}"
fi
	